@@ -15,8 +15,9 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with geoh5py.  If not, see <https://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import uuid
-from typing import Optional
 
 from .group import Group, GroupType
 
@@ -37,6 +38,6 @@ class CustomGroup(Group):
         group_type.workspace._register_group(self)
 
     @classmethod
-    def default_type_uid(cls) -> Optional[uuid.UUID]:
+    def default_type_uid(cls) -> uuid.UUID | None:
         raise RuntimeError(f"No predefined static type UUID for {cls}.")
         # return None
