@@ -20,7 +20,7 @@ from __future__ import annotations
 import uuid
 import weakref
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, List, Optional, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, TypeVar, cast
 
 if TYPE_CHECKING:
     from .. import workspace as ws
@@ -33,15 +33,15 @@ class EntityType(ABC):
 
     _attribute_map = {"Description": "description", "ID": "uid", "Name": "name"}
 
-    def __init__(self, workspace: "ws.Workspace", **kwargs):
+    def __init__(self, workspace: ws.Workspace, **kwargs):
         assert workspace is not None
         self._workspace = weakref.ref(workspace)
 
         self._uid: uuid.UUID = uuid.uuid4()
-        self._name: Optional[str] = "Entity"
-        self._description: Optional[str] = None
+        self._name: str | None = "Entity"
+        self._description: str | None = None
         self._existing_h5_entity = False
-        self._modified_attributes: List[str] = []
+        self._modified_attributes: list[str] = []
 
         for attr, item in kwargs.items():
             try:
@@ -60,7 +60,7 @@ class EntityType(ABC):
         return self._attribute_map
 
     @property
-    def description(self) -> Optional[str]:
+    def description(self) -> str | None:
         return self._description
 
     @description.setter
@@ -92,8 +92,8 @@ class EntityType(ABC):
 
     @classmethod
     def find(
-        cls: Type[TEntityType], workspace: "ws.Workspace", type_uid: uuid.UUID
-    ) -> Optional[TEntityType]:
+        cls: type[TEntityType], workspace: ws.Workspace, type_uid: uuid.UUID
+    ) -> TEntityType | None:
         """Finds in the given Workspace the EntityType with the given UUID for
         this specific EntityType implementation class.
 
@@ -110,7 +110,7 @@ class EntityType(ABC):
         return self._modified_attributes
 
     @modified_attributes.setter
-    def modified_attributes(self, values: Union[List, str]):
+    def modified_attributes(self, values: list | str):
         if self.existing_h5_entity:
             if not isinstance(values, list):
                 values = [values]
@@ -126,11 +126,11 @@ class EntityType(ABC):
     @staticmethod
     @abstractmethod
     def _is_abstract() -> bool:
-        """ Trick to prevent from instantiating abstract base class. """
+        """Trick to prevent from instantiating abstract base class."""
         return True
 
     @property
-    def name(self) -> Optional[str]:
+    def name(self) -> str | None:
         return self._name
 
     @name.setter
@@ -147,7 +147,7 @@ class EntityType(ABC):
         return self._uid
 
     @uid.setter
-    def uid(self, uid: Union[str, uuid.UUID]):
+    def uid(self, uid: str | uuid.UUID):
         if isinstance(uid, str):
             uid = uuid.UUID(uid)
         self.modified_attributes = "attributes"
@@ -155,7 +155,7 @@ class EntityType(ABC):
         self._uid = uid
 
     @property
-    def workspace(self) -> "ws.Workspace":
+    def workspace(self) -> ws.Workspace:
         """
         :obj:`~geoh5py.workspace.workspace.Workspace` registering this type.
         """
